# Various UNets for ECG waveform segmentation


## Implemented

1. vanilla UNet (LUDB, ref. [1])
2. subtraction Unet (CPSC2019)

## TODO

1. UNet++
2. U2Net (U square net)
3. to add more....

## References

1. Moskalenko, Viktor, Nikolai Zolotykh, and Grigory Osipov. "Deep Learning for ECG Segmentation." International Conference on Neuroinformatics. Springer, Cham, 2019.
2. to add more...
